==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/CalloutLabelUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutLabelUpdatingEventArgsDescription } from "./CalloutLabelUpdatingEventArgsDescription";
/**
 * @hidden
 */
var CalloutLabelUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CalloutLabelUpdatingEventArgsDescriptionMetadata, _super);
    function CalloutLabelUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalloutLabelUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (CalloutLabelUpdatingEventArgsDescriptionMetadata.a == null) {
            CalloutLabelUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalloutLabelUpdatingEventArgsDescriptionMetadata.c(CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.k(CalloutLabelUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
        SeriesDescriptionMetadata.d(a);
    };
    CalloutLabelUpdatingEventArgsDescriptionMetadata.c = function (a) {
        a.item("XValueRef", "(w:XValue,j:xValue,wf:XValue)DataRef");
        a.item("YValueRef", "(w:YValue,j:yValue,wf:YValue)DataRef");
        a.item("ItemRef", "(w:Item,j:item,wf:Item)DataRef");
        a.item("Series", "ExportedType:Series");
        a.item("SeriesName", "String");
        a.item("LabelRef", "(w:Label,j:label,wf:Label)DataRef");
    };
    CalloutLabelUpdatingEventArgsDescriptionMetadata.d = function (a) {
        CalloutLabelUpdatingEventArgsDescriptionMetadata.b(a);
        a.ac("CalloutLabelUpdatingEventArgs", function () { return new CalloutLabelUpdatingEventArgsDescription(); });
        a.ab("CalloutLabelUpdatingEventArgs", CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
    };
    CalloutLabelUpdatingEventArgsDescriptionMetadata.$t = markType(CalloutLabelUpdatingEventArgsDescriptionMetadata, 'CalloutLabelUpdatingEventArgsDescriptionMetadata');
    CalloutLabelUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutLabelUpdatingEventArgsDescriptionMetadata;
}(Base));
export { CalloutLabelUpdatingEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/CalloutLabelUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutLabelUpdatingEventArgsDescription } from "./CalloutLabelUpdatingEventArgsDescription";
/**
 * @hidden
 */
var CalloutLabelUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CalloutLabelUpdatingEventArgsDescriptionMetadata, _super);
    function CalloutLabelUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalloutLabelUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (CalloutLabelUpdatingEventArgsDescriptionMetadata.a == null) {
            CalloutLabelUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalloutLabelUpdatingEventArgsDescriptionMetadata.c(CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.k(CalloutLabelUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
        SeriesDescriptionMetadata.d(a);
    };
    CalloutLabelUpdatingEventArgsDescriptionMetadata.c = function (a) {
        a.item("XValueRef", "(w:XValue,j:xValue,wf:XValue)DataRef");
        a.item("YValueRef", "(w:YValue,j:yValue,wf:YValue)DataRef");
        a.item("ItemRef", "(w:Item,j:item,wf:Item)DataRef");
        a.item("Series", "ExportedType:Series");
        a.item("SeriesName", "String");
        a.item("LabelRef", "(w:Label,j:label,wf:Label)DataRef");
    };
    CalloutLabelUpdatingEventArgsDescriptionMetadata.d = function (a) {
        CalloutLabelUpdatingEventArgsDescriptionMetadata.b(a);
        a.ae("CalloutLabelUpdatingEventArgs", function () { return new CalloutLabelUpdatingEventArgsDescription(); });
        a.ad("CalloutLabelUpdatingEventArgs", CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
    };
    CalloutLabelUpdatingEventArgsDescriptionMetadata.$t = markType(CalloutLabelUpdatingEventArgsDescriptionMetadata, 'CalloutLabelUpdatingEventArgsDescriptionMetadata');
    CalloutLabelUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutLabelUpdatingEventArgsDescriptionMetadata;
}(Base));
export { CalloutLabelUpdatingEventArgsDescriptionMetadata };
